@@ -6,12 +6,13 @@ class TOKEN:
     POINT: str = "."
     STRING: str = "str"
     CODE: str = "code"
+    NEW_LINE: str = "\n"
 
 
 class KEYWORD:
     """Constants keywords for airphin."""
 
-    CONVERT_MARK: str = "-airphin"
+    MIGRATE_MARK: str = "-airphin"
 
 
 class REGEXP:
